==> jc-1.4.0.tar.gz: java/awt/Canvas.h <==
// public class java.awt.Canvas

// class file dependencies
// @dep_class be549b8b9281e6d7 java_awt_Canvas
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_Component

#include "java/awt/Component.h"

#ifndef _JC_java_awt_Canvas_H_
#define _JC_java_awt_Canvas_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_GraphicsConfiguration$object;
struct _jc_java_awt_image_BufferStrategy$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleContext$object;

// Typedefs
typedef struct _jc_java_awt_Canvas$sub_refs	_jc_java_awt_Canvas$sub_refs;
typedef struct _jc_java_awt_Canvas$sub_nonrefs	_jc_java_awt_Canvas$sub_nonrefs;
typedef struct _jc_java_awt_Canvas$refs	_jc_java_awt_Canvas$refs;
typedef struct _jc_java_awt_Canvas$nonrefs	_jc_java_awt_Canvas$nonrefs;
typedef struct _jc_java_awt_Canvas$object	_jc_java_awt_Canvas$object;

typedef struct _jc_java_awt_Canvas$fields_struct	_jc_java_awt_Canvas$fields_struct;
typedef const struct _jc_java_awt_Canvas$vmethods	_jc_java_awt_Canvas$vmethods;
typedef const struct _jc_java_awt_Canvas$vtable	_jc_java_awt_Canvas$vtable;
typedef const struct _jc_java_awt_Canvas$vtype	_jc_java_awt_Canvas$vtype;

// Class fields structure
struct _jc_java_awt_Canvas$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Canvas$fields_struct _jc_java_awt_Canvas$class_fields;

// Constructors
extern void _jc_java_awt_Canvas$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_Canvas$object *);
extern void _jc_java_awt_Canvas$method$_init$e9abde475967473f(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_GraphicsConfiguration$object *);

// Virtual methods
extern void _jc_java_awt_Canvas$method$addNotify$ce98320b2caf56cf(_jc_env *, struct _jc_java_awt_Canvas$object *);
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_java_awt_Canvas$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_java_awt_Canvas$object *);
extern struct _jc_java_awt_image_BufferStrategy$object *_jc_java_awt_Canvas$method$getBufferStrategy$b6ec41112d443d8d(_jc_env *, struct _jc_java_awt_Canvas$object *);
extern struct _jc_java_awt_GraphicsConfiguration$object *_jc_java_awt_Canvas$method$getGraphicsConfigurationImpl$ec66405a58e07d8c(_jc_env *, struct _jc_java_awt_Canvas$object *);
extern void _jc_java_awt_Canvas$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_java_awt_Canvas$method$update$71f5c0c292688da7(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_Graphics$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Canvas$method_info$addNotify$ce98320b2caf56cf;
extern _jc_method _jc_java_awt_Canvas$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_java_awt_Canvas$method_info$getBufferStrategy$b6ec41112d443d8d;
extern _jc_method _jc_java_awt_Canvas$method_info$getGraphicsConfigurationImpl$ec66405a58e07d8c;
extern _jc_method _jc_java_awt_Canvas$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_java_awt_Canvas$method_info$update$71f5c0c292688da7;

// Virtual methods structure
struct _jc_java_awt_Canvas$vmethods {
	void	(*addNotify$ce98320b2caf56cf)(_jc_env *, struct _jc_java_awt_Canvas$object *);
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_java_awt_Canvas$object *);
	struct _jc_java_awt_image_BufferStrategy$object	*(*getBufferStrategy$b6ec41112d443d8d)(_jc_env *, struct _jc_java_awt_Canvas$object *);
	struct _jc_java_awt_GraphicsConfiguration$object	*(*getGraphicsConfigurationImpl$ec66405a58e07d8c)(_jc_env *, struct _jc_java_awt_Canvas$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_Graphics$object *);
	void	(*update$71f5c0c292688da7)(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_Graphics$object *);
};

// Vtable
struct _jc_java_awt_Canvas$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Canvas$vmethods	java_awt_Canvas;
};

// Vtype
struct _jc_java_awt_Canvas$vtype {
	_jc_type			type;
	_jc_java_awt_Canvas$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Canvas$sub_refs {
	struct _jc_java_awt_GraphicsConfiguration$object	*graphicsConfiguration;
	struct _jc_java_awt_image_BufferStrategy$object	*bufferStrategy;
};

// Reference instance fields (object)
struct _jc_java_awt_Canvas$refs {
    _jc_java_awt_Canvas$sub_refs	java_awt_Canvas;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Canvas$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Canvas$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Canvas$sub_nonrefs	java_awt_Canvas;
};

// Object instance structure
struct _jc_java_awt_Canvas$object {
	_jc_java_awt_Canvas$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Canvas$vtype	*vtype;
	_jc_java_awt_Canvas$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Canvas$vtype _jc_java_awt_Canvas$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Canvas, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Canvas$class_object;

#endif	/* _JC_java_awt_Canvas_H_ */

==> jc-1.4.5.tar.gz: java/awt/Canvas.h <==
// public class java.awt.Canvas

// class file dependencies
// @dep_class be549b8b9281e6d7 java_awt_Canvas
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_Component

#include "java/awt/Component.h"

#ifndef _JC_java_awt_Canvas_H_
#define _JC_java_awt_Canvas_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_GraphicsConfiguration$object;
struct _jc_java_awt_image_BufferStrategy$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleContext$object;

// Typedefs
typedef struct _jc_java_awt_Canvas$sub_refs	_jc_java_awt_Canvas$sub_refs;
typedef struct _jc_java_awt_Canvas$sub_nonrefs	_jc_java_awt_Canvas$sub_nonrefs;
typedef struct _jc_java_awt_Canvas$refs	_jc_java_awt_Canvas$refs;
typedef struct _jc_java_awt_Canvas$nonrefs	_jc_java_awt_Canvas$nonrefs;
typedef struct _jc_java_awt_Canvas$object	_jc_java_awt_Canvas$object;

typedef struct _jc_java_awt_Canvas$fields_struct	_jc_java_awt_Canvas$fields_struct;
typedef const struct _jc_java_awt_Canvas$vmethods	_jc_java_awt_Canvas$vmethods;
typedef const struct _jc_java_awt_Canvas$vtable	_jc_java_awt_Canvas$vtable;
typedef const struct _jc_java_awt_Canvas$vtype	_jc_java_awt_Canvas$vtype;

// Class fields structure
struct _jc_java_awt_Canvas$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Canvas$fields_struct _jc_java_awt_Canvas$class_fields;

// Constructors
extern void _jc_java_awt_Canvas$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Canvas$method$_init$e9abde475967473f(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_GraphicsConfiguration$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Canvas$method$addNotify$ce98320b2caf56cf(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_java_awt_Canvas$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_BufferStrategy$object *_jc_java_awt_Canvas$method$getBufferStrategy$b6ec41112d443d8d(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_GraphicsConfiguration$object *_jc_java_awt_Canvas$method$getGraphicsConfigurationImpl$ec66405a58e07d8c(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Canvas$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Canvas$method$update$71f5c0c292688da7(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Canvas$method_info$addNotify$ce98320b2caf56cf;
extern _jc_method _jc_java_awt_Canvas$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_java_awt_Canvas$method_info$getBufferStrategy$b6ec41112d443d8d;
extern _jc_method _jc_java_awt_Canvas$method_info$getGraphicsConfigurationImpl$ec66405a58e07d8c;
extern _jc_method _jc_java_awt_Canvas$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_java_awt_Canvas$method_info$update$71f5c0c292688da7;

// Virtual methods structure
struct _jc_java_awt_Canvas$vmethods {
	void	(*addNotify$ce98320b2caf56cf)(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_image_BufferStrategy$object	*(*getBufferStrategy$b6ec41112d443d8d)(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_GraphicsConfiguration$object	*(*getGraphicsConfigurationImpl$ec66405a58e07d8c)(_jc_env *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*update$71f5c0c292688da7)(_jc_env *, struct _jc_java_awt_Canvas$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Canvas$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Canvas$vmethods	java_awt_Canvas;
};

// Vtype
struct _jc_java_awt_Canvas$vtype {
	_jc_type			type;
	_jc_java_awt_Canvas$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Canvas$sub_refs {
	struct _jc_java_awt_GraphicsConfiguration$object	*graphicsConfiguration;
	struct _jc_java_awt_image_BufferStrategy$object	*bufferStrategy;
};

// Reference instance fields (object)
struct _jc_java_awt_Canvas$refs {
    _jc_java_awt_Canvas$sub_refs	java_awt_Canvas;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Canvas$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Canvas$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Canvas$sub_nonrefs	java_awt_Canvas;
};

// Object instance structure
struct _jc_java_awt_Canvas$object {
	_jc_java_awt_Canvas$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Canvas$vtype	*vtype;
	_jc_java_awt_Canvas$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Canvas$vtype _jc_java_awt_Canvas$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Canvas, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Canvas$class_object;

#endif	/* _JC_java_awt_Canvas_H_ */
